@@ -9,22 +9,18 @@ from ..core.lexemes import Q, Avg, Count
 class TestSQLConnector(TestCase):
 
     def test_no_connector(self):
-        with self.assertRaises(ImproperlyConfigured):
-            SphinxSearch('index').process()
-
-        with self.assertRaises(ImproperlyConfigured):
-            SphinxSnippets('index', ['data'], 'query').process()
+        self.assertRaises(ImproperlyConfigured, lambda: SphinxSearch('index').process())
+        self.assertRaises(ImproperlyConfigured, lambda: SphinxSnippets('index', ['data'], 'query').process())
 
 
 class TestSQLProcessor(TestCase):
 
-    @patch.object(SphinxConnector, 'connect', Mock())
     def setUp(self):
         self.SphinxSearch = SphinxConnector()
 
     def test_instance(self):
-        self.assertIsInstance(self.SphinxSearch('index'), SphinxSearch)
-        self.assertIsInstance(self.SphinxSearch.Index('index'), SphinxSearch)
+        self.assertTrue(isinstance(self.SphinxSearch('index'), SphinxSearch))
+        self.assertTrue(isinstance(self.SphinxSearch.Index('index'), SphinxSearch))
 
     def test_basic_query(self):
         a = self.SphinxSearch('index').get_sxql()
@@ -56,8 +52,7 @@ class TestSQLProcessor(TestCase):
         a = self.SphinxSearch('index').limit(0, 20).get_sxql()
         self.assertEqual(a, u'SELECT * FROM index LIMIT 0,20')
 
-        with self.assertRaises(SphinxQLSyntaxException):
-            self.SphinxSearch('index').limit(0, 200).limit(10, 60).get_sxql()
+        self.assertRaises(SphinxQLSyntaxException, lambda: self.SphinxSearch('index').limit(0, 200).limit(10, 60).get_sxql())
 
     def test_group_by(self):
         a = self.SphinxSearch('index').group_by('title').get_sxql()
@@ -66,8 +61,7 @@ class TestSQLProcessor(TestCase):
         b = self.SphinxSearch('index').group_by().get_sxql()
         self.assertEqual(b, u'SELECT * FROM index')
 
-        with self.assertRaises(SphinxQLSyntaxException):
-            self.SphinxSearch('index').group_by('title').group_by('name').get_sxql()
+        self.assertRaises(SphinxQLSyntaxException, lambda: self.SphinxSearch('index').group_by('title').group_by('name').get_sxql())
 
     def test_cluster(self):
         a = self.SphinxSearch('index').cluster('title').get_sxql()
@@ -82,15 +76,13 @@ class TestSQLProcessor(TestCase):
         d = self.SphinxSearch('index').select(Count()).group_by('title').get_sxql()
         self.assertEqual(a, d)
 
-        with self.assertRaises(SphinxQLSyntaxException):
-            self.SphinxSearch('index').cluster('title').cluster('name').get_sxql()
+        self.assertRaises(SphinxQLSyntaxException, lambda: self.SphinxSearch('index').cluster('title').cluster('name').get_sxql())
 
     def test_within_group_order_by(self):
         a = self.SphinxSearch('index').within_group_order_by('title', 'ASC').get_sxql()
         self.assertEqual(a, u'SELECT * FROM index WITHIN GROUP ORDER BY title ASC')
 
-        with self.assertRaises(SphinxQLSyntaxException):
-            self.SphinxSearch('index').within_group_order_by('title', 'ASC').within_group_order_by('name', 'DESC').get_sxql()
+        self.assertRaises(SphinxQLSyntaxException, lambda: self.SphinxSearch('index').within_group_order_by('title', 'ASC').within_group_order_by('name', 'DESC').get_sxql())
 
     def test_match(self):
         a = self.SphinxSearch('index').match('Hello').get_sxql()
@@ -115,7 +107,7 @@ class TestSQLProcessor(TestCase):
         d = self.SphinxSearch('index').filter(Q(id__eq=1, id__gte=5)).get_sxql()
         d_results = ["SELECT *, (id>=5 AND id=1) AS cnd FROM index WHERE cnd>0",
                      "SELECT *, (id=1 AND id>=5) AS cnd FROM index WHERE cnd>0"]
-        self.assertIn(d, d_results)
+        self.assertTrue(d in d_results)
 
         e = (self.SphinxSearch('index').filter(Q(id__eq=1) | Q(id__gte=5))
                                        .filter(Q(counter__lt=42, id__lt=20))
@@ -124,7 +116,7 @@ class TestSQLProcessor(TestCase):
         e_possible_q_orders = ["(id=1) OR (id>=5) AND (counter<42 AND id<20)",
                                "(id=1) OR (id>=5) AND (id<20, counter<42)"]
         e_possible_queries = ["SELECT *, {or_q} AS cnd FROM index WHERE cnd>0 AND id=2".format(or_q=or_q) for or_q in e_possible_q_orders]
-        self.assertIn(e, e_possible_queries)
+        self.assertTrue(e in e_possible_queries)
 
         f = self.SphinxSearch('index').filter(~Q(id__eq=1, id__gte=5) & Q(counter__eq=1, counter__gte=100)).get_sxql()
         f_possible_q_orders = ["(id=1 OR id>=5) AND (counter=1 AND counter>=100)",
@@ -132,7 +124,7 @@ class TestSQLProcessor(TestCase):
                                "(id>=5 OR id=1) AND (counter=1 AND counter>=100)",
                                "(id>=5 OR id=1) AND (counter>=100 AND counter=1)"]
         f_possible_queries = ["SELECT *, {or_q} AS cnd FROM index WHERE cnd>0".format(or_q=or_q) for or_q in f_possible_q_orders]
-        self.assertIn(f, f_possible_queries)
+        self.assertTrue(f in f_possible_queries)
 
         g = (self.SphinxSearch('index').filter(institute__eq=6506)
                                        .filter(location__eq=1565)
@@ -142,7 +134,7 @@ class TestSQLProcessor(TestCase):
         g_possible_q_orders = ["(id>=5 AND id=1)", "(id=1 AND id>=5)"]
         g_possible_queries = ["SELECT *, COUNT(*) AS num, {or_q} AS cnd FROM index WHERE institute=6506 AND location=1565 AND cnd>0 GROUP BY location"
                               .format(or_q=or_q) for or_q in g_possible_q_orders]
-        self.assertIn(g, g_possible_queries)
+        self.assertTrue(g in g_possible_queries)
 
     def test_match_with_filters(self):
         a = self.SphinxSearch('index').match('Hello').filter(id__gte=1).get_sxql()
@@ -155,12 +147,11 @@ class TestSQLProcessor(TestCase):
 
 class TestSnippets(TestCase):
 
-    @patch.object(SphinxConnector, 'connect', Mock())
     def setUp(self):
         self.SphinxSearch = SphinxConnector()
 
     def test_instance(self):
-        self.assertIsInstance(self.SphinxSearch.Snippets('index', ['only good news'], query='Good News'), SphinxSnippets)
+        self.assertTrue(isinstance(self.SphinxSearch.Snippets('index', ['only good news'], query='Good News'), SphinxSnippets))
 
     def test_basic(self):
         query_1 = self.SphinxSearch.Snippets('index', ['only good news', 'news'], query='Good News').get_sxql()
